.. _hyper_mode:

Hyper Mode
==========

**Hyper-mode** adapts our lens models to the specific strong lens we are fitting, for example congregating the source
pixelization to the reconstructed source's intrinsic morphology.

The readthedocs overview for **hyper-mode** is not written yet. However, checkout
`Chapter 5 of the HowToLens lectures <https://pyautolens.readthedocs.io/en/latest/howtolens/chapter_5_hyper_mode/index.html>`_
for a complete description of **hyper-mode**.